| package |
package := Package name: 'HTTP-Encoding'.
package paxVersion: 1;
	basicComment: ''.


package classNames
	add: #HtmlEncodingPolicy;
	add: #HTTPEncodingPolicy;
	add: #UrlEncodingPolicy;
	yourself.

package binaryGlobalNames: (Set new
	yourself).

package globalAliases: (Set new
	yourself).

package setPrerequisites: (IdentitySet new
	add: '..\..\Object Arts\Dolphin\Base\Dolphin';
	yourself).

package!

"Class Definitions"!

Object subclass: #HTTPEncodingPolicy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
HTTPEncodingPolicy subclass: #HtmlEncodingPolicy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
HTTPEncodingPolicy subclass: #UrlEncodingPolicy
	instanceVariableNames: ''
	classVariableNames: 'UrlEncodingTable'
	poolDictionaries: ''
	classInstanceVariableNames: ''!

"Global Aliases"!


"Loose Methods"!

"End of package definition"!

"Source Globals"!

"Classes"!

HTTPEncodingPolicy guid: (GUID fromString: '{57407232-0BB5-48E1-A7A2-FBC4EC6C8312}')!
HTTPEncodingPolicy comment: ''!
!HTTPEncodingPolicy categoriesForClass!Kernel-Objects! !
!HTTPEncodingPolicy methodsFor!

decode: aString
	| readStream writeStream |
	readStream := aString readStream.
	writeStream := aString class writeStream: aString size.
	[ readStream atEnd ] whileFalse: [ self decodeFrom: readStream onto: writeStream ].
	^writeStream contents!

decodeFrom: readStream onto: writeStream 
	^self subclassResponsibility!

encode: aString
	| stream |
	stream := aString class writeStream: aString size.
	aString do: [ :ea | self encodeCharacter: ea onto: stream ].
	^stream contents!

encodeCharacter: aCharacter onto: stream 
	^self subclassResponsibility! !
!HTTPEncodingPolicy categoriesFor: #decode:!operations!public! !
!HTTPEncodingPolicy categoriesFor: #decodeFrom:onto:!private! !
!HTTPEncodingPolicy categoriesFor: #encode:!operations!public! !
!HTTPEncodingPolicy categoriesFor: #encodeCharacter:onto:!private! !

HtmlEncodingPolicy guid: (GUID fromString: '{CB147FDD-5547-4A51-A138-1DBA0D27879F}')!
HtmlEncodingPolicy comment: ''!
!HtmlEncodingPolicy categoriesForClass!Kernel-Objects! !
!HtmlEncodingPolicy methodsFor!

decodeFrom: readStream onto: writeStream
	| character |
	character := readStream next.
	character = $& ifTrue: [ 
		| buffer |
		readStream peek = $# ifTrue: [ 
			readStream skip: 1. 
			buffer := readStream upTo: $;.
			^writeStream nextPut: (buffer asNumber + 1) asCharacter ].
		buffer := readStream upTo: $;.
		buffer = 'amp' ifTrue: [ ^writeStream nextPut: $& ].
		buffer = 'quot' ifTrue: [ ^writeStream nextPut: $" ]. 
		buffer = 'lt' ifTrue: [ ^writeStream nextPut: $< ]. 
		buffer = 'gt' ifTrue: [ ^writeStream nextPut: $> ]. ].
	^writeStream nextPut: character!

encodeCharacter: aCharacter onto: stream
	aCharacter > $~
		ifTrue:
			[ ^stream
				nextPutAll: '&#';
				display: aCharacter asInteger - 1;
				nextPut: $; ].
	aCharacter = $" ifTrue: [ ^stream nextPutAll: '&quot;' ].
	aCharacter = $< ifTrue: [ ^stream nextPutAll: '&lt;' ].
	aCharacter = $> ifTrue: [ ^stream nextPutAll: '&gt;' ].
	aCharacter = $& ifTrue: [ ^stream nextPutAll: '&amp;' ].
	^stream nextPut: aCharacter! !
!HtmlEncodingPolicy categoriesFor: #decodeFrom:onto:!private! !
!HtmlEncodingPolicy categoriesFor: #encodeCharacter:onto:!private! !

UrlEncodingPolicy guid: (GUID fromString: '{6A4423BC-CBB8-4C11-9C38-CB0601F269D0}')!
UrlEncodingPolicy comment: ''!
!UrlEncodingPolicy categoriesForClass!Kernel-Objects! !
!UrlEncodingPolicy methodsFor!

decodeFrom: readStream onto: writeStream
	| character |
	character := readStream next.
	character = $+ ifTrue: [ ^writeStream nextPut: $  ].
	character = $%
		ifTrue:
			[ ^writeStream nextPut: (Integer readFrom: (readStream next: 2) readStream radix: 16) asCharacter ].
	^writeStream nextPut: character!

encodeCharacter: aCharacter onto: stream
	(aCharacter between: $0 and: $9) ifTrue: [ ^stream nextPut: aCharacter ].
	(aCharacter between: $a and: $z) ifTrue: [ ^stream nextPut: aCharacter ].
	(aCharacter between: $A and: $Z) ifTrue: [ ^stream nextPut: aCharacter ].
	aCharacter = $  ifTrue: [ ^stream nextPut: $+ ].
	(#($- $_ $. $!!!! $~ $* $\ $( $)) identityIncludes: aCharacter)
		ifTrue: [ ^stream nextPut: aCharacter ].
	^stream nextPutAll: (UrlEncodingTable at: aCharacter asInteger + 1)! !
!UrlEncodingPolicy categoriesFor: #decodeFrom:onto:!private! !
!UrlEncodingPolicy categoriesFor: #encodeCharacter:onto:!private! !

!UrlEncodingPolicy class methodsFor!

initialize
	"self initialize"

	UrlEncodingTable := #('%00' '%01' '%02' '%03' '%04' '%05' '%06' '%07' '%08' '%09' '%0A' '%0B' '%0C' '%0D' '%0E' '%0F' '%10' '%11' '%12' '%13' '%14' '%15' '%16' '%17' '%18' '%19' '%1A' '%1B' '%1C' '%1D' '%1E' '%1F' '%20' '%21' '%22' '%23' '%24' '%25' '%26' '%27' '%28' '%29' '%2A' '%2B' '%2C' '%2D' '%2E' '%2F' '%30' '%31' '%32' '%33' '%34' '%35' '%36' '%37' '%38' '%39' '%3A' '%3B' '%3C' '%3D' '%3E' '%3F' '%40' '%41' '%42' '%43' '%44' '%45' '%46' '%47' '%48' '%49' '%4A' '%4B' '%4C' '%4D' '%4E' '%4F' '%50' '%51' '%52' '%53' '%54' '%55' '%56' '%57' '%58' '%59' '%5A' '%5B' '%5C' '%5D' '%5E' '%5F' '%60' '%61' '%62' '%63' '%64' '%65' '%66' '%67' '%68' '%69' '%6A' '%6B' '%6C' '%6D' '%6E' '%6F' '%70' '%71' '%72' '%73' '%74' '%75' '%76' '%77' '%78' '%79' '%7A' '%7B' '%7C' '%7D' '%7E' '%7F' '%80' '%81' '%82' '%83' '%84' '%85' '%86' '%87' '%88' '%89' '%8A' '%8B' '%8C' '%8D' '%8E' '%8F' '%90' '%91' '%92' '%93' '%94' '%95' '%96' '%97' '%98' '%99' '%9A' '%9B' '%9C' '%9D' '%9E' '%9F' '%A0' '%A1' '%A2' '%A3' '%A4' '%A5' '%A6' '%A7' '%A8' '%A9' '%AA' '%AB' '%AC' '%AD' '%AE' '%AF' '%B0' '%B1' '%B2' '%B3' '%B4' '%B5' '%B6' '%B7' '%B8' '%B9' '%BA' '%BB' '%BC' '%BD' '%BE' '%BF' '%C0' '%C1' '%C2' '%C3' '%C4' '%C5' '%C6' '%C7' '%C8' '%C9' '%CA' '%CB' '%CC' '%CD' '%CE' '%CF' '%D0' '%D1' '%D2' '%D3' '%D4' '%D5' '%D6' '%D7' '%D8' '%D9' '%DA' '%DB' '%DC' '%DD' '%DE' '%DF' '%E0' '%E1' '%E2' '%E3' '%E4' '%E5' '%E6' '%E7' '%E8' '%E9' '%EA' '%EB' '%EC' '%ED' '%EE' '%EF' '%F0' '%F1' '%F2' '%F3' '%F4' '%F5' '%F6' '%F7' '%F8' '%F9' '%FA' '%FB' '%FC' '%FD' '%FE' '%FF')! !
!UrlEncodingPolicy class categoriesFor: #initialize!public! !

"Binary Globals"!

